// scripts/constants/block_lists.js

// --- Original Block Lists (for Presets like Remove Trees/Liquids/Foliage) ---
export const TREE_BLOCK_IDS = ["minecraft:oak_log", "minecraft:spruce_log", "minecraft:birch_log", "minecraft:jungle_log", "minecraft:acacia_log", "minecraft:dark_oak_log", "minecraft:mangrove_log", "minecraft:cherry_log", "minecraft:stripped_oak_log", "minecraft:stripped_spruce_log", "minecraft:stripped_birch_log", "minecraft:stripped_jungle_log", "minecraft:stripped_acacia_log", "minecraft:stripped_dark_oak_log", "minecraft:stripped_mangrove_log", "minecraft:stripped_cherry_log", "minecraft:oak_leaves", "minecraft:spruce_leaves", "minecraft:birch_leaves", "minecraft:jungle_leaves", "minecraft:acacia_leaves", "minecraft:dark_oak_leaves", "minecraft:mangrove_leaves", "minecraft:cherry_leaves", "minecraft:azalea_leaves", "minecraft:flowering_azalea_leaves", "minecraft:mangrove_roots"];
export const TREE_BLOCK_ID_SET = new Set(TREE_BLOCK_IDS);

export const LIQUID_BLOCK_IDS = ["minecraft:water", "minecraft:seagrass", "minecraft:flowing_water", "minecraft:lava", "minecraft:flowing_lava"];
export const LIQUID_BLOCK_ID_SET = new Set(LIQUID_BLOCK_IDS);

// This set is still useful for a generic 'Remove Foliage' preset action
export const FOLIAGE_BLOCK_IDS = [
    "minecraft:bush", "minecraft:firefly_bush", "minecraft:leaf_litter", "minecraft:pink_petals",
    // Grasses & Ferns
    "minecraft:short_grass", "minecraft:tall_grass", "minecraft:fern", "minecraft:large_fern",
    "minecraft:short_dry_grass", "minecraft:tall_dry_grass",
    // Small Plants & Flowers
    "minecraft:deadbush", "minecraft:poppy", "minecraft:dandelion", "minecraft:blue_orchid",
    "minecraft:allium", "minecraft:azure_bluet", "minecraft:red_tulip", "minecraft:orange_tulip",
    "minecraft:white_tulip", "minecraft:pink_tulip", "minecraft:oxeye_daisy", "minecraft:cornflower",
    "minecraft:lily_of_the_valley", "minecraft:wither_rose", "minecraft:torchflower", "minecraft:pitcher_plant",
    // Tall Flowers
    "minecraft:sunflower", "minecraft:lilac", "minecraft:rose_bush", "minecraft:peony",
    // Other Ground Cover / Climbers
    "minecraft:vine", "minecraft:lily_pad", "minecraft:brown_mushroom", "minecraft:red_mushroom",
    "minecraft:crimson_fungus", "minecraft:warped_fungus", "minecraft:crimson_roots", "minecraft:warped_roots",
    "minecraft:nether_sprouts", "minecraft:weeping_vines", "minecraft:twisting_vines",
    "minecraft:sugar_cane", "minecraft:sweet_berry_bush", "minecraft:glow_lichen",
    "minecraft:hanging_roots", "minecraft:moss_carpet", "minecraft:pink_petals",
    // Water Plants
    "minecraft:kelp", "minecraft:seagrass",
    "minecraft:wheat", "minecraft:potatoes", "minecraft:carrots", "minecraft:beetroots",
    "minecraft:melon_stem", "minecraft:pumpkin_stem", "minecraft:pitcher_crop",
    // Dripleaf & Azalea
    "minecraft:small_dripleaf_block", "minecraft:big_dripleaf", "minecraft:spore_blossom",
    "minecraft:azalea", "minecraft:flowering_azalea",
];
export const FOLIAGE_BLOCK_ID_SET = new Set(FOLIAGE_BLOCK_IDS);


// --- Foliage Brush Specific Definitions ---

// Define Sets for common ground types for reuse in presets
const standardGround = new Set(["minecraft:grass_block", "minecraft:dirt", "minecraft:podzol", "minecraft:mycelium", "minecraft:dirt_with_roots", "minecraft:farmland", "minecraft:moss_block"]);
const sandGround = new Set(["minecraft:sand", "minecraft:red_sand", "minecraft:suspicious_sand", "minecraft:suspicious_gravel"]);
const dirtAndSandGround = new Set([...standardGround, ...sandGround]);
const mudGround = new Set(["minecraft:mud", "minecraft:muddy_mangrove_roots"]);
const waterAdjacentGround = new Set([...standardGround, ...sandGround, "minecraft:gravel"]);
const waterSurface = new Set(["minecraft:water"]); // Used for needsWater check

// --- Valid Ground Blocks for Foliage Brush --- <<< MOVED UP
// Define the default set of blocks foliage can be placed ON TOP OF.
// Specific plants can override this with their own `validGround` property in FOLIAGE_PRESETS.
export const VALID_FOLIAGE_GROUND_TYPES = new Set([
    "minecraft:grass_block",
    "minecraft:dirt",
    "minecraft:podzol",
    "minecraft:mycelium",
    "minecraft:dirt_with_roots",
    "minecraft:farmland",
    "minecraft:sand",
    "minecraft:red_sand",
    "minecraft:moss_block",
    "minecraft:mud",
    "minecraft:clay",
    // Add other relevant ground types if needed (e.g., coarse_dirt?)
]);

/**
 * Defines the plant lists and placement rules for different biome presets.
 * `id`: The block ID to place.
 * `weight`: Relative chance of this plant being chosen.
 * `state?`: Optional block state object (e.g., `{ upper_block_bit: false }`).
 * `validGround?`: Optional Set of block IDs this plant can be placed ON (defaults to VALID_FOLIAGE_GROUND_TYPES).
 * `needsWater?`: Optional boolean, true if the plant needs to be placed ON a water block (e.g., lily pad).
 */
export const FOLIAGE_PRESETS = {
    'Forest': [
        // Trees
        { id: "minecraft:oak_sapling", weight: 5, validGround: standardGround },
        { id: "minecraft:spruce_sapling", weight: 3, validGround: standardGround },
        { id: "minecraft:birch_sapling", weight: 3, validGround: standardGround },
        // Ground Cover
        { id: "minecraft:short_grass", weight: 30, validGround: standardGround },
        { id: "minecraft:tall_grass", state: { upper_block_bit: false }, weight: 20, validGround: standardGround },
        { id: "minecraft:fern", weight: 15, validGround: standardGround },
        { id: "minecraft:large_fern", state: { upper_block_bit: false }, weight: 5, validGround: standardGround },
        // Flowers & Mushrooms
        { id: "minecraft:poppy", weight: 3, validGround: standardGround },
        { id: "minecraft:dandelion", weight: 3, validGround: standardGround },
        { id: "minecraft:brown_mushroom", weight: 2, validGround: standardGround },
        { id: "minecraft:red_mushroom", weight: 2, validGround: standardGround },
        // Bushes
        { id: "minecraft:azalea", weight: 1, validGround: standardGround },
        { id: "minecraft:flowering_azalea", weight: 1, validGround: standardGround },
    ],
    'Plains': [
        { id: "minecraft:short_grass", weight: 40, validGround: standardGround },
        { id: "minecraft:tall_grass", state: { upper_block_bit: false }, weight: 35, validGround: standardGround },
        { id: "minecraft:poppy", weight: 5, validGround: standardGround },
        { id: "minecraft:dandelion", weight: 5, validGround: standardGround },
        { id: "minecraft:azure_bluet", weight: 3, validGround: standardGround },
        { id: "minecraft:cornflower", weight: 3, validGround: standardGround },
        { id: "minecraft:oxeye_daisy", weight: 3, validGround: standardGround },
        { id: "minecraft:sunflower", state: { upper_block_bit: false }, weight: 1, validGround: standardGround },
        { id: "minecraft:torchflower", weight: 1, validGround: standardGround },
    ],
    'Desert': [
        { id: "minecraft:deadbush", weight: 10, validGround: sandGround },
        { id: "minecraft:cactus", weight: 3, validGround: sandGround },
        { id: "minecraft:short_dry_grass", weight: 2, validGround: sandGround },
    ],
    'Savanna': [
        { id: "minecraft:acacia_sapling", weight: 3, validGround: standardGround },
        { id: "minecraft:short_grass", weight: 25, validGround: standardGround },
        { id: "minecraft:tall_grass", state: { upper_block_bit: false }, weight: 35, validGround: standardGround },
        { id: "minecraft:short_dry_grass", weight: 5, validGround: standardGround },
        { id: "minecraft:tall_dry_grass", weight: 5, validGround: standardGround },
    ],
    'Taiga': [
        { id: "minecraft:spruce_sapling", weight: 6, validGround: standardGround },
        { id: "minecraft:fern", weight: 20, validGround: standardGround },
        { id: "minecraft:large_fern", state: { upper_block_bit: false }, weight: 15, validGround: standardGround },
        { id: "minecraft:sweet_berry_bush", state: { growth: 3 }, weight: 8, validGround: standardGround }, // Place fully grown
        { id: "minecraft:brown_mushroom", weight: 3, validGround: standardGround },
        { id: "minecraft:red_mushroom", weight: 3, validGround: standardGround },
        { id: "minecraft:short_grass", weight: 10, validGround: standardGround },
        // { id: "minecraft:podzol", weight: 5, validGround: new Set(["minecraft:dirt"]) },
    ],
    'Swamp': [
        { id: "minecraft:oak_sapling", weight: 2, validGround: standardGround },
        { id: "minecraft:waterlily", weight: 15, needsWater: true },
        { id: "minecraft:short_grass", weight: 10, validGround: standardGround },
        { id: "minecraft:deadbush", weight: 1, validGround: standardGround },
        { id: "minecraft:brown_mushroom", weight: 6, validGround: standardGround },
        { id: "minecraft:red_mushroom", weight: 6, validGround: standardGround },
        { id: "minecraft:sugar_cane", weight: 5, validGround: waterAdjacentGround },
        { id: "minecraft:blue_orchid", weight: 3, validGround: standardGround },
        // Vines would need adjacent block check - skip for now
    ],
    'MangroveSwamp': [
        { id: "minecraft:mangrove_propagule", weight: 10, validGround: new Set([...standardGround, ...mudGround]) },
        // { id: "minecraft:mangrove_roots", weight: 3 }, // Placement complex
        // { id: "minecraft:mud", weight: 5, validGround: new Set(["minecraft:dirt", "minecraft:grass_block"]) }, // Replacing ground complex
        { id: "minecraft:waterlily", weight: 15, needsWater: true },
        { id: "minecraft:brown_mushroom", weight: 2, validGround: standardGround },
        { id: "minecraft:red_mushroom", weight: 2, validGround: standardGround },
    ],
    'LushCaves': [
        { id: "minecraft:moss_carpet", weight: 25, validGround: VALID_FOLIAGE_GROUND_TYPES },
        { id: "minecraft:short_grass", weight: 10, validGround: standardGround },
        { id: "minecraft:azalea", weight: 5, validGround: standardGround },
        { id: "minecraft:flowering_azalea", weight: 3, validGround: standardGround },
        { id: "minecraft:small_dripleaf_block", weight: 8, validGround: new Set(["minecraft:clay", "minecraft:moss_block", "minecraft:dirt", "minecraft:farmland", "minecraft:grass_block", "minecraft:mud"]) },
        { id: "minecraft:big_dripleaf", state: { height: "tip" }, weight: 3, validGround: new Set(["minecraft:clay", "minecraft:moss_block", "minecraft:dirt", "minecraft:farmland", "minecraft:grass_block", "minecraft:mud"]) },
    ],
    'CherryGrove': [
        { id: "minecraft:cherry_sapling", weight: 10, validGround: standardGround },
        { id: "minecraft:short_grass", weight: 20, validGround: standardGround },
        { id: "minecraft:dandelion", weight: 2, validGround: standardGround },
        { id: "minecraft:poppy", weight: 2, validGround: standardGround },
        { id: "minecraft:pink_petals", weight: 15, validGround: standardGround }, // State randomized in core logic
        { id: "minecraft:allium", weight: 3, validGround: standardGround },
    ],
    'FlowerForest': [
        { id: "minecraft:poppy", weight: 5, validGround: standardGround },
        { id: "minecraft:dandelion", weight: 5, validGround: standardGround },
        { id: "minecraft:azure_bluet", weight: 5, validGround: standardGround },
        { id: "minecraft:cornflower", weight: 5, validGround: standardGround },
        { id: "minecraft:oxeye_daisy", weight: 5, validGround: standardGround },
        { id: "minecraft:allium", weight: 4, validGround: standardGround },
        { id: "minecraft:blue_orchid", weight: 3, validGround: standardGround },
        { id: "minecraft:red_tulip", weight: 3, validGround: standardGround },
        { id: "minecraft:orange_tulip", weight: 3, validGround: standardGround },
        { id: "minecraft:white_tulip", weight: 3, validGround: standardGround },
        { id: "minecraft:pink_tulip", weight: 3, validGround: standardGround },
        { id: "minecraft:lilac", state: { upper_block_bit: false }, weight: 3, validGround: standardGround },
        { id: "minecraft:rose_bush", state: { upper_block_bit: false }, weight: 3, validGround: standardGround },
        { id: "minecraft:peony", state: { upper_block_bit: false }, weight: 3, validGround: standardGround },
        { id: "minecraft:torchflower", weight: 2, validGround: standardGround },
    ],
};