// scripts/events/player_leave.js

import { world } from "@minecraft/server";
import {
    PlayerStateMaps,
    deletePlayerMapData, // Use the corrected export name
    getPlayerClipboard // <<< Need to get clipboard data
} from "../state/player_state.js";
// <<< Need structure manager
import { StructureManager } from "@minecraft/server"; // This import is fine, but world.structureManager is used directly

// const structureManager = world.structureManager; // Can get it directly from world

/** Sets up the listener to clean up player data when they leave the world. */
export function setupPlayerLeaveListener() {
    world.afterEvents.playerLeave.subscribe(eventData => {
        const playerId = eventData.playerId;

        // --- Clean up Structure API clipboard for the leaving player ---
        try {
            // Construct a minimal player-like object for getPlayerClipboard if it expects an object with an id
            const playerLike = { id: playerId };
            const clipboardData = getPlayerClipboard(playerLike);
            if (clipboardData?.structureId) {
                try {
                    // Delete structure from memory
                    world.structureManager.delete(clipboardData.structureId);
                    // console.log(`[WorldEdit] Deleted structure ${clipboardData.structureId} for leaving player ${playerId}`);
                } catch (e) {
                    // Ignore error if structure doesn't exist (e.g., already deleted or never created)
                    if (e.message && !e.message.toLowerCase().includes("structure not found")) {
                        console.warn(`[PlayerLeave] Error deleting structure ${clipboardData.structureId} for player ${playerId}: ${e}`);
                    }
                }
            }
        } catch (e) {
            console.error(`[PlayerLeave] Error accessing clipboard data for player ${playerId}: ${e}`);
        }

        // --- Clean up map data ---
        deletePlayerMapData(PlayerStateMaps.selection, playerId);
        deletePlayerMapData(PlayerStateMaps.clipboard, playerId); // This map stores the clipboard metadata
        deletePlayerMapData(PlayerStateMaps.undo, playerId);
        deletePlayerMapData(PlayerStateMaps.redo, playerId);

        console.log(`[WorldEdit] Cleaned up state data for leaving player ${playerId}`);
    });
}
