// main.js

import { world, system, ItemStack, EquipmentSlot } from '@minecraft/server';
import { setupAllListeners } from './events/index.js';
import { VERSION } from './constants/index.js';

// Setup all event listeners when the script loads
setupAllListeners();

//========================================================================

// Define multiple books with their respective pages
const BOOKS = {
    "book1": [
        "bn:we_bk_pg1",
        "bn:we_bk_pg2",
        "bn:we_bk_pg3",
        "bn:we_bk_pg4",
        "bn:we_bk_pg5",
        "bn:we_bk_pg6",
        "bn:we_bk_pg7",
        "bn:we_bk_pg8",
        "bn:we_bk_pg9",
        "bn:we_bk_pg10",
        "bn:we_bk_pg11",
        "bn:we_bk_pg12",
        "bn:we_bk_pg13",
        "bn:we_bk_pg14",
        "bn:we_bk_pg15"
    ],
    "book2": [
        "bn:we_ebk_pg1",
        "bn:we_ebk_pg2",
        "bn:we_ebk_pg3",
        "bn:we_ebk_pg4",
        "bn:we_ebk_pg5",
        "bn:we_ebk_pg6",
        "bn:we_ebk_pg7",
        "bn:we_ebk_pg8",
        "bn:we_ebk_pg9",
        "bn:we_ebk_pg10",
        "bn:we_ebk_pg11",
        "bn:we_ebk_pg12",
        "bn:we_ebk_pg13",
        "bn:we_ebk_pg14",
        "bn:we_ebk_pg15"
    ]
};

world.beforeEvents.itemUse.subscribe(ev => {
    const item = ev.itemStack;
    const player = ev.source;
    const equippable = player.getComponent("minecraft:equippable");
    const isSneaking = player.isSneaking;

    system.run(() => {
        let currentBook = null;
        let currentIndex = -1;

        for (const [bookName, pages] of Object.entries(BOOKS)) {
            const index = pages.indexOf(item.typeId);
            if (index !== -1) {
                currentBook = pages;
                currentIndex = index;
                break;
            }
        }

        if (currentBook && currentIndex !== -1) {
            let nextIndex;

            if (isSneaking) {
                nextIndex = (currentIndex - 1 + currentBook.length) % currentBook.length;
            } else {
                nextIndex = (currentIndex + 1) % currentBook.length;
            }

            const nextItem = new ItemStack(currentBook[nextIndex]);

            equippable.setEquipment(EquipmentSlot.Mainhand, nextItem);
            player.playSound("item.book.page_turn");
        }
    });
});


//=================================================================


const TAG_TO_CHECK = "bn_we_1_0";
const ITEM_ID_1 = "bn:we_bk_pg1";
const ITEM_ID_2 = "bn:we_ebk_pg1";

world.afterEvents.playerSpawn.subscribe(eventData => {
    const { player, initialSpawn } = eventData;

    system.run(() => {
        try {

            const hasTag = player.hasTag(TAG_TO_CHECK);

            if (!hasTag) {

                const item1 = new ItemStack(ITEM_ID_1, 1);
                const item2 = new ItemStack(ITEM_ID_2, 1);

                const inventory = player.getComponent("inventory");
                if (inventory) {
                    inventory.container.addItem(item1);
                    inventory.container.addItem(item2);
                } else {
                    console.error(`Could not get inventory for player ${player.name}. Trying command fallback.`);
                    player.runCommandAsync(`give @s ${ITEM_ID_1} 1`);
                    player.runCommandAsync(`give @s ${ITEM_ID_2} 1`);
                }


                player.addTag(TAG_TO_CHECK);

            } else {
            }
        } catch (error) {
            console.error(`Error processing player spawn for ${player.name}: ${error}`);
            if (error.stack) {
                console.error(error.stack);
            }
        }
    });
});
