// scripts/ui/edit_selection_menu.js

import { Player, system } from "@minecraft/server";
import { ModalFormData } from "@minecraft/server-ui";
import { MAX_EXPAND_CONTRACT } from "../constants/index.js";
import { editSelectionInPlace } from "../core/edit_selection.js";

/**
 * Shows the ModalForm to get Edit Selection parameters (Rotation, Mirror, Offset).
 * @param {Player} player The player initiating the action.
 */
export async function showEditSelectionForm(player) {
    // Define dropdown options
    const rotationOptions = ["None (0°)", "90°", "180°", "270°"]; // Index maps roughly to StructureRotation enum
    const mirrorOptions = ["None", "X", "Z", "XZ"]; // Index maps roughly to StructureMirrorAxis enum
 
    const form = new ModalFormData()
        .title("Edit Selection In Place")
        .dropdown("Rotation", rotationOptions, 0) // 0: Rotation Index (Default 0 = None)
        .dropdown("Mirror", mirrorOptions, 0) // 1: Mirror Index (Default 0 = None)
        .slider("Offset X", -MAX_EXPAND_CONTRACT, MAX_EXPAND_CONTRACT, 1, 0) // 2: Offset X (Default 0)
        .slider("Offset Y", -MAX_EXPAND_CONTRACT, MAX_EXPAND_CONTRACT, 1, 0) // 3: Offset Y (Default 0)
        .slider("Offset Z", -MAX_EXPAND_CONTRACT, MAX_EXPAND_CONTRACT, 1, 0) // 4: Offset Z (Default 0)
        .toggle("Include Entities", false); // 5: Include Entities (Default false for in-place editing)

    try {
        const response = await form.show(player);

        if (response.canceled || !response.formValues) {
            player.sendMessage("§eEdit Selection cancelled.");
            return;
        }

        // --- Process Form Input ---
        const rotationIndex = response.formValues[0];
        const mirrorIndex = response.formValues[1];
        const offsetX = response.formValues[2];
        const offsetY = response.formValues[3];
        const offsetZ = response.formValues[4];
        const includeEntities = response.formValues[5];

        // Map indices/values to data needed by core function
        const rotationString = rotationOptions[rotationIndex]; // e.g., "90°"
        const mirrorString = mirrorOptions[mirrorIndex]; // e.g., "X"

        // --- Call Core Logic ---
        // Use system.run for the potentially long operation
        system.run(async () => {
            if (player.isValid()) {
                await editSelectionInPlace(
                    player,
                    rotationString,
                    mirrorString,
                    offsetX,
                    offsetY,
                    offsetZ,
                    includeEntities
                );
            }
        });

    } catch (e) {
        console.error(`[Edit Selection Form] Error: ${e}\n${e.stack}`);
        player.sendMessage("§cError displaying or processing edit selection form.");
    }
}