// scripts/ui/main_menu.js

import { Player, system } from "@minecraft/server";
import { ActionFormData } from "@minecraft/server-ui";
import { getPlayerSelection, getActiveSavedPaletteName } from "../state/index.js"; // Renamed getter
import { calculateVolume } from "../utils/index.js";
// Import the NEW core functions/UI forms
import { countBlocks } from "../core/analyze_selection.js";
import { showFillOptionsMenu } from "./fill_menu.js";
import { showStackRepeatForm } from "./stack_repeat_menu.js";
import { showEditSelectionForm } from "./edit_selection_menu.js";
import { showReplaceBlocksForm } from "./replace_menu.js";
import { showPaletteMenu } from "./palette_menu.js";
import { showPresetsMenu } from "./presets_menu.js";
import { showTerrainGeneratorForm } from "./terrain_menu.js";

/** Shows the main Selection Editor menu */
export async function showEditMenu(player) {
    const selection = getPlayerSelection(player);
    const { posA, posB, selectionState, activePaletteData, activePaletteIsDirty } = selection; // Renamed fields
    const activeSavedPalette = getActiveSavedPaletteName(player); // Renamed getter
    const activePaletteStatus = activePaletteData ? ` (${activePaletteData.length} items${activePaletteIsDirty ? ', §cunsaved§r' : ''})` : ' (Empty/Inactive)'; // Renamed
    const hasSelection = selectionState === 2;

    let bodyText = `§eSelection Status:§r ${selectionState === 2 ? `§aComplete` : selectionState === 1 ? `§6Pos A Set` : `§cInactive`}§r\n`;

    if (selectionState === 1 && posA) { bodyText += ` Pos A: ${posA.x}, ${posA.y}, ${posA.z}\n Waiting for Pos B.\n`; }
    else if (selectionState === 2 && posA && posB) { bodyText += ` Pos A: ${posA.x}, ${posA.y}, ${posA.z}\n Pos B: ${posB.x}, ${posB.y}, ${posB.z}\n Volume: ${calculateVolume(posA, posB)} blocks\n`; }
    bodyText += `§eLoaded Saved Palette:§r ${activeSavedPalette ? `§b${activeSavedPalette}` : "§7None"}§r\n`; // Renamed
    bodyText += `§eActive Palette:§r ${activePaletteData ? `§6Current${activePaletteStatus}` : "§7Empty/Inactive"}§r`; // Renamed

    const form = new ActionFormData().title("Selection Editor").body(bodyText)
        .button("Fill Options...", "textures/ui/icon_recipe_construction")
        .button("Replace Blocks...", "textures/items/bucket_empty")
        .button("Generate Terrain...", "textures/ui/world_glyph_color_2x")
        .button("Count Blocks", "textures/ui/icon_book_writable")
        .button("Stack/Repeat Selection...", "textures/ui/icon_multiplayer")
        .button("Edit Selection In Place...", "textures/ui/settings_glyph")
        .button("Manage Palettes", "textures/ui/inventory_icon")
        .button("Preset Actions...", "textures/ui/settings_glyph_color_2x")
        .button("Cancel", "textures/ui/cancel");

    try {
        const response = await form.show(player);

        if (response.canceled || response.selection === undefined || response.selection === 8) {
            return;
        }

        const needsSelection = [0, 1, 2, 3, 4, 5, 7].includes(response.selection);
        if (!hasSelection && needsSelection) {
            player.sendMessage("§cPlease complete the selection first (Set Pos A & Pos B).");
            system.run(async () => { if (player.isValid()) await showEditMenu(player); });
            return;
        }

        switch (response.selection) {
            case 0: await showFillOptionsMenu(player); break;
            case 1: await showReplaceBlocksForm(player); break;
            case 2: await showTerrainGeneratorForm(player); break;
            case 3: await countBlocks(player); break;
            case 4: await showStackRepeatForm(player); break;
            case 5: await showEditSelectionForm(player); break;
            case 6: await showPaletteMenu(player); break;
            case 7: await showPresetsMenu(player); break;
        }
    } catch (error) {
        console.error(`[WorldEdit Edit Menu] Error: ${error}\n${error.stack}`);
        player.sendMessage("§cAn error occurred opening or handling the edit menu.");
    }
}
