// scripts/ui/message_display.js

import { Player } from "@minecraft/server";
import { MessageFormData } from "@minecraft/server-ui";

/**
 * Displays a simple message form to the player.
 * @param {Player} player The player to show the message to.
 * @param {string} title The title of the message window.
 * @param {string} body The body text of the message.
 */
export async function showMessage(player, title, body) {
    const form = new MessageFormData()
        .title(title)
        .body(body)
        .button1("OK"); // Use button1 as the primary confirmation

    try {
        await form.show(player);
    } catch (e) {
        // Log error, but don't bother player if form fails to show
        console.error(`[ShowMessage Form] Error: ${e}`);
        // Fallback to chat?
        // player.sendMessage(`${title}\n${body}`);
    }
}