// scripts/ui/replace_menu.js

import { Player, system } from "@minecraft/server";
import { ModalFormData } from "@minecraft/server-ui";
import { replaceBlocks } from "../core/index.js"; // Import the core logic function

/**
 * Shows the ModalForm to get parameters for the Replace Blocks operation.
 * @param {Player} player The player initiating the action.
 */
export async function showReplaceBlocksForm(player) {
    const form = new ModalFormData()
        .title("Replace Blocks in Selection")
        .textField("Blocks to Replace (IDs, comma-sep)", "e.g. stone, dirt, gravel", "") // 0
        .textField("Replace With (ID or id:wt,...)", "e.g. minecraft:air / glass:1", ""); // 1

    try {
        const response = await form.show(player);

        if (response.canceled || !response.formValues) {
            player.sendMessage("§eReplace Blocks cancelled.");
            return;
        }

        // --- Process Form Input ---
        const targetBlocksString = response.formValues[0].trim();
        const replacementString = response.formValues[1].trim();

        // Basic validation
        if (!targetBlocksString) {
            player.sendMessage("§c'Blocks to Replace' cannot be empty.");
            return;
        }
        if (!replacementString) {
            player.sendMessage("§c'Replace With' cannot be empty.");
            return;
        }

        // --- Call Core Logic ---
        // Use system.run as replaceBlocks might iterate many blocks
        system.run(async () => {
            if (player.isValid()) {
                await replaceBlocks(player, targetBlocksString, replacementString);
            }
        });

    } catch (e) {
        console.error(`[Replace Blocks Form] Error: ${e}\n${e.stack}`);
        player.sendMessage("§cError displaying or processing replace blocks form.");
    }
}