// scripts/ui/stack_repeat_menu.js

import { Player, system } from "@minecraft/server";
import { ModalFormData } from "@minecraft/server-ui";
import { MAX_STACK_COUNT } from "../constants/index.js";
import { stackRepeatSelection } from "../core/stack_repeat.js"; // Import the core logic

/**
 * Shows the ModalForm to get Stack/Repeat parameters from the player.
 * @param {Player} player The player initiating the action.
 */
export async function showStackRepeatForm(player) {
    const form = new ModalFormData()
        .title("Stack/Repeat Selection")
        .slider("Repeat Count", 1, MAX_STACK_COUNT, 1, 1) // 0: Count (1 to MAX)
        .dropdown("Direction", ["Up (+Y)", "Down (-Y)", "North (-Z)", "South (+Z)", "East (+X)", "West (-X)"], 0) // 1: Direction (Index 0 is Up)
        .textField("Offset X", "Additional X offset per copy", "0") // 2: Offset X
        .textField("Offset Y", "Additional Y offset per copy", "0") // 3: Offset Y
        .textField("Offset Z", "Additional Z offset per copy", "0"); // 4: Offset Z
    // Removed: .toggle("Include Air Blocks", false);

    try {
        const response = await form.show(player);

        if (response.canceled || !response.formValues) {
            player.sendMessage("§eStack/Repeat cancelled.");
            return;
        }

        // --- Process Form Input ---
        const repeatCount = response.formValues[0];
        const directionIndex = response.formValues[1];
        const offsetXStr = response.formValues[2];
        const offsetYStr = response.formValues[3];
        const offsetZStr = response.formValues[4];
        // Removed: includeAir variable processing

        // --- Validate Offsets ---
        const offsetX = parseInt(offsetXStr, 10);
        const offsetY = parseInt(offsetYStr, 10);
        const offsetZ = parseInt(offsetZStr, 10);

        if (isNaN(offsetX) || isNaN(offsetY) || isNaN(offsetZ)) {
            player.sendMessage("§cInvalid offset value. Offsets must be whole numbers.");
            return;
        }

        // --- Determine Direction Vector ---
        let directionVec = { x: 0, y: 0, z: 0 };
        switch (directionIndex) {
            case 0: directionVec = { x: 0, y: 1, z: 0 }; break; // Up
            case 1: directionVec = { x: 0, y: -1, z: 0 }; break; // Down
            case 2: directionVec = { x: 0, y: 0, z: -1 }; break; // North
            case 3: directionVec = { x: 0, y: 0, z: 1 }; break; // South
            case 4: directionVec = { x: 1, y: 0, z: 0 }; break; // East
            case 5: directionVec = { x: -1, y: 0, z: 0 }; break; // West
        }

        // --- Call Core Logic ---
        // Use system.run to ensure the potentially long-running operation doesn't block
        system.run(async () => {
            if (player.isValid()) {
                // Call core function WITHOUT the includeAir argument
                await stackRepeatSelection(player, repeatCount, directionVec, offsetX, offsetY, offsetZ);
            }
        });

    } catch (e) {
        console.error(`[Stack/Repeat Form] Error: ${e}\n${e.stack}`);
        player.sendMessage("§cError displaying or processing stack/repeat form.");
    }
}